@@ -4,6 +4,7 @@
 #' @param available Genotyped individuals IDs. 
 #' @param lLociFreq Allele frequencies.
 #' @param rseed Seed used for simulations.
+#' @import paramlink
 #' @import igraph
 #' @export
 #' @return A ped object.
@@ -20,11 +21,11 @@ preparePed<-function(ped,available,lLociFreq,rseed=NULL){
      afreq<-afreq[-iout]
     }
 
-    paux   <- markerSimfb(ped, N=1, alleles=alleles,afreq=afreq,verbose=FALSE)
+    paux   <- markerSim(ped, N=1, alleles=alleles,afreq=afreq,verbose=FALSE)
     mallele<- matrix(attr(paux$markerdata[[1]],"alleles")[paux$markerdata[[1]]],ncol=2)
 
-    maux <- markerfb(ped,allelematrix=mallele,alleles=alleles,afreq=afreq,name=names(lLociFreq)[i])
-    ped  <- addMarkerfb(ped,maux)
+    maux <- marker(ped,allelematrix=mallele,alleles=alleles,afreq=afreq,name=names(lLociFreq)[i])
+    ped  <- addMarker(ped,maux)
  }
 
  inotEv <- ped$orig.ids[!ped$orig.ids%in%available]
